@@ -13,20 +13,20 @@ class Response:
         try:
             return json.loads(self.content)
         except Exception as e:
-            logger.error(e)
+            logger.error(f'格式化json异常:{e}, 数据:{self.content}')
 
     def soup(self):
         try:
             soup = BeautifulSoup(self.content, 'lxml')
             return soup
         except Exception as e:
-            logger.error(e)
+            logger.error(f'格式化soup异常:{e}, 数据:{self.content}')
 
     def text(self):
         try:
             return self.content.decode()
         except Exception as e:
-            logger.error(e)
+            logger.error(f'格式化text异常:{e}, 数据:{self.content}')
 
 
 
